@@ -6,7 +6,7 @@
 
 set -ev
 cd crates/sauron-core && cargo publish && cd - && \
-echo "sleeping for 5s" && sleep 5 &&\
+echo "sleeping" && sleep 20 &&\
 cd crates/sauron-node-macro && cargo publish && cd - &&
-echo "sleeping for 5s" && sleep 5 &&\
+echo "sleeping" && sleep 20 &&\
 cargo publish
